@@ -10,20 +10,22 @@
 
 #define XC_GGA_C_CS1          565 /* A dynamical correlation functional */
 
-#include "maple2c/gga_c_cs1.c"
-
-#define func maple2c_func
-#include "work_gga_c.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_cs1.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_cs1 = {
   XC_GGA_C_CS1,
   XC_CORRELATION,
   "A dynamical correlation functional",
   XC_FAMILY_GGA,
   {&xc_ref_Handy2002_5411, &xc_ref_Proynov2006_436, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-20,
-  0, NULL, NULL,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, work_gga_c, NULL
+  NULL, work_gga, NULL
 };
