@@ -10,20 +10,22 @@
 
 #define XC_GGA_C_GAPLOC  556 /* Gaploc */
 
-#include "maple2c/gga_c_gaploc.c"
-
-#define func maple2c_func
-#include "work_gga_c.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_gaploc.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_gaploc = {
   XC_GGA_C_GAPLOC,
   XC_CORRELATION,
   "Gaploc",
   XC_FAMILY_GGA,
   {&xc_ref_Fabiano2014_2016, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-18,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, work_gga_c, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
