@@ -10,20 +10,22 @@
 
 #define XC_GGA_C_HCTH_A        97 /* HCTH-A                                   */
 
-#include "maple2c/gga_c_hcth_a.c"
-
-#define func maple2c_func
-#include "work_gga_c.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_hcth_a.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_hcth_a = {
   XC_GGA_C_HCTH_A,
   XC_CORRELATION,
   "HCTH-A",
   XC_FAMILY_GGA,
   {&xc_ref_Hamprecht1998_6264, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-16,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, work_gga_c, NULL
+  NULL, work_gga, NULL
 };
