@@ -16,21 +16,38 @@
 
 #define XC_GGA_C_LM          137 /* Langreth and Mehl correlation          */
 
-#include "maple2c/gga_c_lm.c"
+typedef struct{
+  double lm_f;
+} gga_c_lm_params;
 
-#define func maple2c_func
-#include "work_gga_c.c"
+static void
+gga_c_lm_init(xc_func_type *p)
+{
+  assert(p!=NULL && p->params == NULL);
+  p->params = libxc_malloc(sizeof(gga_c_lm_params));
+}
 
+#define N_PAR 1
+static const char  *names[N_PAR]  = {"_f"};
+static const char  *desc[N_PAR]   = { "f parameter" };
+static const double par_lm[N_PAR] = {0.15};
+
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_lm.c"
+#include "work_gga.c"
+
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_lm = {
   XC_GGA_C_LM,
   XC_CORRELATION,
   "Langreth & Mehl",
   XC_FAMILY_GGA,
   {&xc_ref_Langreth1981_446, &xc_ref_Hu1985_391, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-12,
-  0, NULL, NULL,
-  NULL, NULL,
-  NULL, work_gga_c, NULL
+  {N_PAR, names, desc, par_lm, set_ext_params_cpy},
+  gga_c_lm_init, NULL,
+  NULL, work_gga, NULL
 };
-
