@@ -11,20 +11,22 @@
 
 #define XC_GGA_C_OP_B88      87 /* one-parameter progressive functional (B88 version)     */
 
-#include "maple2c/gga_c_op_b88.c"
-
-#define func maple2c_func
-#include "work_gga_c.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_op_b88.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_op_b88 = {
   XC_GGA_C_OP_B88,
   XC_CORRELATION,
   "one-parameter progressive functional (B88 version)",
   XC_FAMILY_GGA,
   {&xc_ref_Tsuneda1999_10664, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-32,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, work_gga_c, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
