@@ -11,21 +11,23 @@
 
 #define XC_GGA_C_Q2D          47 /* Chiodo et al  */
 
-#include "maple2c/gga_c_q2d.c"
-
-#define func maple2c_func
-#include "work_gga_c.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_q2d.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_q2d = {
   XC_GGA_C_Q2D,
   XC_CORRELATION,
   "Chiodo et al",
   XC_FAMILY_GGA,
   {&xc_ref_Chiodo2012_126402, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-10,
-  0, NULL, NULL,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, work_gga_c, NULL
+  NULL, work_gga, NULL
 };
 
