@@ -10,20 +10,22 @@
 
 #define XC_GGA_C_REVTCA        99 /* Tognetti, Cortona, Adamo (revised) */
 
-#include "maple2c/gga_c_revtca.c"
-
-#define func maple2c_func
-#include "work_gga_c.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_c_revtca.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_c_revtca = {
   XC_GGA_C_REVTCA,
   XC_CORRELATION,
   "Tognetti, Cortona, Adamo (revised)",
   XC_FAMILY_GGA,
   {&xc_ref_Tognetti2008_536, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-25,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, work_gga_c, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
