@@ -10,21 +10,22 @@
 
 #define XC_GGA_K_EXP4          597 /* Intermediate form between PBE3 and PBE4 */
 
-#include "maple2c/gga_k_exp4.c"
-
-#define func maple2c_func
-#define XC_KINETIC_FUNCTIONAL
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_k_exp4.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_k_exp4 = {
   XC_GGA_K_EXP4,
   XC_KINETIC,
   "Intermediate form between PBE3 and PBE4",
   XC_FAMILY_GGA,
   {&xc_ref_Karasiev2006_111, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-25,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, work_gga_k, NULL
+  NULL, work_gga, NULL
 };
