@@ -10,20 +10,22 @@
 
 #define XC_GGA_X_CHACHIYO     298 /* Chachiyo exchange */
 
-#include "maple2c/gga_x_chachiyo.c"
-
-#define func xc_gga_x_chachiyo_enhance
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_chachiyo.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_chachiyo = {
   XC_GGA_X_CHACHIYO,
   XC_EXCHANGE,
   "Chachiyo exchange",
   XC_FAMILY_GGA,
-  {&xc_ref_Chachiyo2017, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-25,
-  0, NULL, NULL,
+  {&xc_ref_Chachiyo2020_3485, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, work_gga_x, NULL
+  NULL, work_gga, NULL
 };
