@@ -10,21 +10,22 @@
 
 #define XC_GGA_X_HERMAN          104 /* Herman et al original GGA                  */
 
-#include "maple2c/gga_x_herman.c"
-
-#define func xc_gga_x_herman_enhance
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_herman.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_herman = {
   XC_GGA_X_HERMAN,
   XC_EXCHANGE,
   "Herman Xalphabeta GGA",
   XC_FAMILY_GGA,
   {&xc_ref_Herman1969_807, &xc_ref_Herman1969_827, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
-  NULL, NULL, NULL,
-  work_gga_x,
-  NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
