@@ -8,23 +8,25 @@
 
 #include "util.h"
 
-#define XC_GGA_X_PBEpow         539 /* PBE power */
+#define XC_GGA_X_PBEPOW         539 /* PBE power */
 
-#include "maple2c/gga_x_pbepow.c"
-
-#define func xc_gga_x_pbepow_enhance
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_pbepow.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_pbepow = {
-  XC_GGA_X_PBEpow,
+  XC_GGA_X_PBEPOW,
   XC_EXCHANGE,
   "PBE power",
   XC_FAMILY_GGA,
   {&xc_ref_Bremond2016_244102, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  5e-3, /* Gives NaN for densities as small as 1e-3 */
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, work_gga_x, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-12,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
 
