@@ -10,20 +10,22 @@
 
 #define XC_GGA_X_PBETRANS  291 /* Gradient-based interpolation between PBE and revPBE */
 
-#include "maple2c/gga_x_pbetrans.c"
-
-#define func xc_gga_x_pbetrans_enhance
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_pbetrans.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_pbetrans = {
   XC_GGA_X_PBETRANS,
   XC_EXCHANGE,
   "Gradient-regulated connection-based correction for the PBE exchange",
   XC_FAMILY_GGA,
   {&xc_ref_Bremond2016_1059, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-32,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, work_gga_x, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
