@@ -14,23 +14,25 @@
 static void
 mgga_x_dldf_init(xc_func_type *p)
 {
-  p->cam_alpha   = 0.6144129;
+  xc_hyb_init_hybrid(p, 0.6144129);
 }
 
-#include "maple2c/hyb_mgga_x_dldf.c"
-
-#define func maple2c_func
-#include "work_mgga_x.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/hyb_mgga_x_dldf.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_x_dldf = {
   XC_HYB_MGGA_X_DLDF,
   XC_EXCHANGE,
   "Dispersionless Density Functional",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Pernal2009_263201, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1.0e-22,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   mgga_x_dldf_init, NULL,
-  NULL, NULL, work_mgga_x,
+  NULL, NULL, work_mgga,
 };
