@@ -28,18 +28,21 @@ xc_hyb_mgga_xc_b88b95_init(xc_func_type *p)
   static double funcs_coef[2] = {1.0 - 0.28, 1.0};
 
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = 0.28;
+  xc_hyb_init_hybrid(p, 0.28);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_b88b95 = {
   XC_HYB_MGGA_XC_B88B95,
   XC_EXCHANGE_CORRELATION,
   "Mixture of B88 with BC95 (B1B95)",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Becke1996_1040, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_b88b95_init,
   NULL, NULL, NULL, NULL,
 };
@@ -53,18 +56,21 @@ xc_hyb_mgga_xc_b86b95_init(xc_func_type *p)
   static double funcs_coef[2] = {1.0 - 0.28, 1.0};
 
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = 0.28;
+  xc_hyb_init_hybrid(p, 0.28);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_b86b95 = {
   XC_HYB_MGGA_XC_B86B95,
   XC_EXCHANGE_CORRELATION,
   "Mixture of B86 with BC95",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Becke1996_1040, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_b86b95_init,
   NULL, NULL, NULL, NULL,
 };
@@ -78,18 +84,21 @@ xc_hyb_mgga_xc_pw86b95_init(xc_func_type *p)
   static double funcs_coef[2] = {1.0 - 0.29, 1.0};
 
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = 0.29;
+  xc_hyb_init_hybrid(p, 0.29);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_pw86b95 = {
   XC_HYB_MGGA_XC_PW86B95,
   XC_EXCHANGE_CORRELATION,
   "Mixture of PW86 with BC95",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Becke1996_1040, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_pw86b95_init,
   NULL, NULL, NULL, NULL,
 };
@@ -103,18 +112,21 @@ xc_hyb_mgga_xc_bb1k_init(xc_func_type *p)
   static double funcs_coef[2] = {1.0 - 0.42, 1.0};
 
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = 0.42;
+  xc_hyb_init_hybrid(p, 0.42);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_bb1k = {
   XC_HYB_MGGA_XC_BB1K,
   XC_EXCHANGE_CORRELATION,
   "Mixture of B88 with BC95 from Zhao and Truhlar",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2004_2715, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_bb1k_init,
   NULL, NULL, NULL, NULL,
 };
@@ -128,18 +140,21 @@ xc_hyb_mgga_xc_mpw1b95_init(xc_func_type *p)
   static double funcs_coef[2] = {1.0 - 0.31, 1.0};
 
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = 0.31;
+  xc_hyb_init_hybrid(p, 0.31);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_mpw1b95 = {
   XC_HYB_MGGA_XC_MPW1B95,
   XC_EXCHANGE_CORRELATION,
   "Mixture of mPW91 with BC95 from Zhao and Truhlar",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2004_6908, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_mpw1b95_init,
   NULL, NULL, NULL, NULL,
 };
@@ -153,18 +168,21 @@ xc_hyb_mgga_xc_mpwb1k_init(xc_func_type *p)
   static double funcs_coef[2] = {1.0 - 0.44, 1.0};
 
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = 0.44;
+  xc_hyb_init_hybrid(p, 0.44);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_mpwb1k = {
   XC_HYB_MGGA_XC_MPWB1K,
   XC_EXCHANGE_CORRELATION,
   "Mixture of mPW91 with BC95 for kinetics",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2004_6908, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_mpwb1k_init,
   NULL, NULL, NULL, NULL,
 };
@@ -184,18 +202,21 @@ xc_hyb_mgga_xc_x1b95_init(xc_func_type *p)
   funcs_coef[2] = 1.0;
 
   xc_mix_init(p, 3, funcs_id, funcs_coef);
-  p->cam_alpha = a0;
+  xc_hyb_init_hybrid(p, a0);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_x1b95 = {
   XC_HYB_MGGA_XC_X1B95,
   XC_EXCHANGE_CORRELATION,
   "Mixture of X with BC95",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2004_6908, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_x1b95_init,
   NULL, NULL, NULL, NULL,
 };
@@ -215,18 +236,21 @@ xc_hyb_mgga_xc_xb1k_init(xc_func_type *p)
   funcs_coef[2] = 1.0;
 
   xc_mix_init(p, 3, funcs_id, funcs_coef);
-  p->cam_alpha = a0;
+  xc_hyb_init_hybrid(p, a0);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_xb1k = {
   XC_HYB_MGGA_XC_XB1K,
   XC_EXCHANGE_CORRELATION,
   "Mixture of X with BC95 for kinetics",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2004_6908, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_xb1k_init,
   NULL, NULL, NULL, NULL,
 };
@@ -236,24 +260,31 @@ const xc_func_info_type xc_func_info_hyb_mgga_xc_xb1k = {
 void
 xc_hyb_mgga_xc_pw6b95_init(xc_func_type *p)
 {
-  static int   funcs_id  [2] = {XC_GGA_X_PW91, XC_MGGA_C_BC95};
+  static int    funcs_id  [2] = {XC_GGA_X_MPW91, XC_MGGA_C_BC95};
   static double funcs_coef[2] = {1.0 - 0.28, 1.0};
 
+  static double par_x_pw91[] = {0.00538, 1.7382/(X2S*X2S), 3.8901};
+  static double par_c_bc95[] = {0.03668, 0.00262};
+
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  xc_gga_x_pw91_set_params2(p->func_aux[0], 0.00538, 1.7382/(X2S*X2S), 3.8901);
-  xc_mgga_c_bc95_set_params(p->func_aux[1], 0.03668, 0.00262);
-  p->cam_alpha = 0.28;
+  xc_func_set_ext_params(p->func_aux[0], par_x_pw91);
+  xc_func_set_ext_params(p->func_aux[1], par_c_bc95);
+
+  xc_hyb_init_hybrid(p, 0.28);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_pw6b95 = {
   XC_HYB_MGGA_XC_PW6B95,
   XC_EXCHANGE_CORRELATION,
   "Mixture of PW91 with BC95 from Zhao and Truhlar",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2005_5656, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_pw6b95_init,
   NULL, NULL, NULL, NULL,
 };
@@ -263,24 +294,31 @@ const xc_func_info_type xc_func_info_hyb_mgga_xc_pw6b95 = {
 void
 xc_hyb_mgga_xc_pwb6k_init(xc_func_type *p)
 {
-  static int   funcs_id  [2] = {XC_GGA_X_PW91, XC_MGGA_C_BC95};
+  static int    funcs_id  [2] = {XC_GGA_X_MPW91, XC_MGGA_C_BC95};
   static double funcs_coef[2] = {1.0 - 0.46, 1.0};
 
+  static double par_x_pw91[] = {0.00539, 1.7077/(X2S*X2S), 4.0876};
+  static double par_c_bc95[] = {0.04120, 0.00353};
+
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  xc_gga_x_pw91_set_params2(p->func_aux[0], 0.00539, 1.7077/(X2S*X2S), 4.0876);
-  xc_mgga_c_bc95_set_params(p->func_aux[1], 0.04120, 0.00353);
-  p->cam_alpha = 0.46;
+  xc_func_set_ext_params(p->func_aux[0], par_x_pw91);
+  xc_func_set_ext_params(p->func_aux[1], par_c_bc95);
+
+  xc_hyb_init_hybrid(p, 0.46);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_pwb6k = {
   XC_HYB_MGGA_XC_PWB6K,
   XC_EXCHANGE_CORRELATION,
   "Mixture of PW91 with BC95 from Zhao and Truhlar for kinetics",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2005_5656, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   xc_hyb_mgga_xc_pwb6k_init,
   NULL, NULL, NULL, NULL,
 };
@@ -296,15 +334,18 @@ mgga_xc_tpsslyp1w_init(xc_func_type *p)
   xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_xc_tpsslyp1w = {
   XC_MGGA_XC_TPSSLYP1W,
   XC_EXCHANGE_CORRELATION,
   "TPSSLYP1W",
   XC_FAMILY_MGGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-23,
-  0, NULL, NULL,
-  mgga_xc_tpsslyp1w_init, 
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
+  mgga_xc_tpsslyp1w_init,
   NULL, NULL, NULL, NULL
 };
