@@ -48,63 +48,75 @@ hyb_mgga_xc_kcis_init(xc_func_type *p)
 
   /* Initialize mix */
   funcs_id[0] = xid;
-  funcs_coef[0] = 1.0-exx;
+  funcs_coef[0] = 1.0 - exx;
 
   funcs_id[1] = XC_MGGA_C_KCIS;
   funcs_coef[1] = 1.0;
-  
+
   xc_mix_init(p, 2, funcs_id, funcs_coef);
-  p->cam_alpha = exx;
+  xc_hyb_init_hybrid(p, exx);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_mpw1kcis = {
   XC_HYB_MGGA_XC_MPW1KCIS,
   XC_EXCHANGE_CORRELATION,
   "MPW1KCIS for barrier heights",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2005_2012, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_DEVELOPMENT,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   hyb_mgga_xc_kcis_init,
   NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_mpwkcis1k = {
   XC_HYB_MGGA_XC_MPWKCIS1K,
   XC_EXCHANGE_CORRELATION,
   "MPWKCIS1K for barrier heights",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2005_2012, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_DEVELOPMENT,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   hyb_mgga_xc_kcis_init,
   NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_pbe1kcis = {
   XC_HYB_MGGA_XC_PBE1KCIS,
   XC_EXCHANGE_CORRELATION,
   "PBE1KCIS for binding energies",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2005_415, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_DEVELOPMENT,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   hyb_mgga_xc_kcis_init,
   NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_xc_tpss1kcis = {
   XC_HYB_MGGA_XC_TPSS1KCIS,
   XC_EXCHANGE_CORRELATION,
   "TPSS1KCIS for thermochemistry and kinetics",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Zhao2005_43, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_DEVELOPMENT,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   hyb_mgga_xc_kcis_init,
   NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
