@@ -10,21 +10,22 @@
 
 #define XC_LDA_C_1D_LOOS          26 /* P-F Loos correlation LDA     */
 
-#include "maple2c/lda_c_1d_loos.c"
-
-#define func maple2c_func
-#define XC_DIMENSIONS 1
+#include "decl_lda.h"
+#include "maple2c/lda_exc/lda_c_1d_loos.c"
 #include "work_lda.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_c_1d_loos = {
   XC_LDA_C_1D_LOOS,
   XC_CORRELATION,
   "P-F Loos correlation LDA",
   XC_FAMILY_LDA,
   {&xc_ref_Loos2013_064108, NULL, NULL, NULL, NULL},
-  XC_FLAGS_1D |  XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  XC_FLAGS_1D | MAPLE2C_FLAGS,
   5e-28,
-  0, NULL, NULL,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
   work_lda, NULL, NULL
 };
