@@ -14,20 +14,22 @@
 
 #define XC_LDA_C_GK72  578   /* Gordon and Kim 1972 */
 
-#include "maple2c/lda_c_gk72.c"
-
-#define func maple2c_func
+#include "decl_lda.h"
+#include "maple2c/lda_exc/lda_c_gk72.c"
 #include "work_lda.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_c_gk72 = {
   XC_LDA_C_GK72,
   XC_CORRELATION,
   "Gordon and Kim 1972",
   XC_FAMILY_LDA,
   {&xc_ref_Gordon1972_3122, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-32,
-  0, NULL, NULL,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
   work_lda, NULL, NULL
 };
