@@ -16,57 +16,53 @@ typedef struct {
   double fc, q;
 } lda_c_ml1_params;
 
-static void 
+#define N_PAR 2
+static const char  *names[N_PAR]  = {"_fc", "_q"};
+/* These should be documented better */
+static const char  *desc[N_PAR]   = {"fc", "q"};
+
+static const double par_ml1[N_PAR] = {0.2026, 0.084};
+static const double par_ml2[N_PAR] = {0.266, 0.5};
+
+static void
 lda_c_ml1_init(xc_func_type *p)
 {
-  lda_c_ml1_params *params;
-
   assert(p!=NULL && p->params == NULL);
-  p->params = malloc(sizeof(lda_c_ml1_params));
-  params = (lda_c_ml1_params *) (p->params);
-
-  switch(p->info->number){
-  case XC_LDA_C_ML1:
-    params->fc = 0.2026;
-    params->q  = 0.084;
-    break;
-  case XC_LDA_C_ML2:
-    params->fc = 0.266;
-    params->q  = 0.5;
-    break;
-  default:
-    fprintf(stderr, "Internal error in lda_c_ml1\n");
-    exit(1);
-  }
+  p->params = libxc_malloc(sizeof(lda_c_ml1_params));
 }
 
-#include "maple2c/lda_c_ml1.c"
-
-#define func maple2c_func
+#include "decl_lda.h"
+#include "maple2c/lda_exc/lda_c_ml1.c"
 #include "work_lda.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_c_ml1 = {
   XC_LDA_C_ML1,
   XC_CORRELATION,
   "Modified LSD (version 1) of Proynov and Salahub",
   XC_FAMILY_LDA,
-  {&xc_ref_Proynov1994_7874, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
+  {&xc_ref_Proynov1994_7874, &xc_ref_Proynov1998_12616, NULL, NULL, NULL},
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {N_PAR, names, desc, par_ml1, set_ext_params_cpy},
   lda_c_ml1_init, NULL,
   work_lda, NULL, NULL
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_c_ml2 = {
   XC_LDA_C_ML2,
   XC_CORRELATION,
   "Modified LSD (version 2) of Proynov and Salahub",
   XC_FAMILY_LDA,
-  {&xc_ref_Proynov1994_7874, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
+  {&xc_ref_Proynov1994_7874, &xc_ref_Proynov1998_12616, NULL, NULL, NULL},
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {N_PAR, names, desc, par_ml2, set_ext_params_cpy},
   lda_c_ml1_init, NULL,
   work_lda, NULL, NULL
 };
