@@ -11,20 +11,22 @@
 
 #define XC_LDA_C_RC04          27 /* Ragot-Cortona */
 
-#include "maple2c/lda_c_rc04.c"
-
-#define func maple2c_func
+#include "decl_lda.h"
+#include "maple2c/lda_exc/lda_c_rc04.c"
 #include "work_lda.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_c_rc04 = {
   XC_LDA_C_RC04,
   XC_CORRELATION,
   "Ragot-Cortona",
   XC_FAMILY_LDA,
   {&xc_ref_Ragot2004_7671, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
   work_lda, NULL, NULL
 };
