@@ -15,20 +15,22 @@
 
 #define XC_LDA_K_ZLP     550   /* kinetic energy version of ZLP */
 
-#include "maple2c/lda_k_zlp.c"
-
-#define func maple2c_func
+#include "decl_lda.h"
+#include "maple2c/lda_exc/lda_k_zlp.c"
 #include "work_lda.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_k_zlp = {
   XC_LDA_K_ZLP,
   XC_KINETIC,
   "Wigner including kinetic energy contribution",
   XC_FAMILY_LDA,
   {&xc_ref_Fuentealba1995_31, &xc_ref_Zhao1993_918, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
   work_lda, NULL, NULL
 };
