@@ -21,20 +21,22 @@
   understand why...
 */
 
-#include "maple2c/mgga_c_cs.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_c_cs.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_c_cs = {
   XC_MGGA_C_CS,
   XC_CORRELATION,
   "Colle and Salvetti",
   XC_FAMILY_MGGA,
   {&xc_ref_Colle1975_329, &xc_ref_Lee1988_785, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_NEEDS_LAPLACIAN | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-24,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, NULL, work_mgga_c,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_LAPLACIAN | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, NULL, work_mgga,
 };
