@@ -12,22 +12,24 @@
 #define XC_MGGA_C_REVSCAN       582 /* revised SCAN correlation */
 #define XC_MGGA_C_REVSCAN_VV10  585 /* revised SCAN correlation */
 
-#include "maple2c/mgga_c_revscan.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_c_revscan.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_c_revscan = {
   XC_MGGA_C_REVSCAN,
   XC_CORRELATION,
   "revised SCAN",
   XC_FAMILY_MGGA,
-  {&xc_ref_Mezei2018, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-26,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, NULL, work_mgga_c,
+  {&xc_ref_Mezei2018_2469, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, NULL, work_mgga,
 };
 
 static void
@@ -42,15 +44,18 @@ mgga_c_revscan_vv10_init(xc_func_type *p)
   p->nlc_C = 0.0093;
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_c_revscan_vv10 = {
   XC_MGGA_C_REVSCAN_VV10,
   XC_CORRELATION,
   "REVSCAN + VV10 correlation",
   XC_FAMILY_MGGA,
-  {&xc_ref_Mezei2018, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_VV10 | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32,
-  0, NULL, NULL,
-  mgga_c_revscan_vv10_init,
-  NULL, NULL, NULL, NULL
+  {&xc_ref_Mezei2018_2469, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_VV10 | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  mgga_c_revscan_vv10_init, NULL,
+  NULL, NULL, NULL
 };
