@@ -10,21 +10,22 @@
 
 #define XC_MGGA_X_GVT4          204 /* GVT4 from Van Voorhis and Scuseria */
 
-#include "maple2c/mgga_x_gvt4.c"
-
-#define func xc_mgga_x_gvt4_enhance
-#include "work_mgga_x.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_x_gvt4.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_x_gvt4 = {
   XC_MGGA_X_GVT4,
   XC_EXCHANGE,
   "GVT4 (X part of VSXC)",
   XC_FAMILY_MGGA,
   {&xc_ref_VanVoorhis1998_400, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1.0e-23,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, NULL,        /* this is not an LDA                   */
-  work_mgga_x,
+  NULL, NULL, work_mgga,
 };
