@@ -14,10 +14,6 @@
 #define XC_MGGA_X_MN15_L        260 /* MN15-L exhange functional from Minnesota           */
 #define XC_HYB_MGGA_X_MN15      268 /* MN15 hybrid exchange functional from Minnesota     */
 
-typedef struct{
-  const double c[40];
-} mgga_x_mn12_params;
-
 /* the ordering is
 CC000 [ 0], CC001 [ 1], CC002 [ 2], CC003 [ 3], CC004 [ 4], CC005 [ 5]
 CC010 [ 6], CC011 [ 7], CC012 [ 8], CC013 [ 9], CC014 [10],
@@ -30,7 +26,94 @@ CC200 [30], CC201 [31], CC202 [32], CC203 [33],
 CC210 [34], CC211 [35], CC212 [36],
 CC300 [37], CC301 [38], CC302 [39]
 */
-static const mgga_x_mn12_params par_mn12_l = {{
+typedef struct{
+  const double c[40];
+} mgga_x_mn12_params;
+
+/* Local functionals */
+#define N_PAR_L 40
+static const char *names_l[N_PAR_L] = {
+  "_CC000", "_CC001", "_CC002", "_CC003", "_CC004", "_CC005",
+  "_CC010", "_CC011", "_CC012", "_CC013", "_CC014",
+  "_CC020", "_CC021", "_CC022", "_CC023",
+  "_CC030", "_CC031", "_CC032",
+  "_CC100", "_CC101", "_CC102", "_CC103", "_CC104",
+  "_CC110", "_CC111", "_CC112", "_CC113",
+  "_CC120", "_CC121", "_CC122",
+  "_CC200", "_CC201", "_CC202", "_CC203",
+  "_CC210", "_CC211", "_CC212",
+  "_CC300", "_CC301", "_CC302"
+};
+static const char *desc_l[N_PAR_L] = {
+  "CC000", "CC001", "CC002", "CC003", "CC004", "CC005",
+  "CC010", "CC011", "CC012", "CC013", "CC014",
+  "CC020", "CC021", "CC022", "CC023",
+  "CC030", "CC031", "CC032",
+  "CC100", "CC101", "CC102", "CC103", "CC104",
+  "CC110", "CC111", "CC112", "CC113",
+  "CC120", "CC121", "CC122",
+  "CC200", "CC201", "CC202", "CC203",
+  "CC210", "CC211", "CC212",
+  "CC300", "CC301", "CC302"
+};
+
+/* Global hybrid */
+#define N_PAR_H 41
+static const char *names_h[N_PAR_H] = {
+  "_CC000", "_CC001", "_CC002", "_CC003", "_CC004", "_CC005",
+  "_CC010", "_CC011", "_CC012", "_CC013", "_CC014",
+  "_CC020", "_CC021", "_CC022", "_CC023",
+  "_CC030", "_CC031", "_CC032",
+  "_CC100", "_CC101", "_CC102", "_CC103", "_CC104",
+  "_CC110", "_CC111", "_CC112", "_CC113",
+  "_CC120", "_CC121", "_CC122",
+  "_CC200", "_CC201", "_CC202", "_CC203",
+  "_CC210", "_CC211", "_CC212",
+  "_CC300", "_CC301", "_CC302", "_ax"
+};
+static const char *desc_h[N_PAR_H] = {
+  "CC000", "CC001", "CC002", "CC003", "CC004", "CC005",
+  "CC010", "CC011", "CC012", "CC013", "CC014",
+  "CC020", "CC021", "CC022", "CC023",
+  "CC030", "CC031", "CC032",
+  "CC100", "CC101", "CC102", "CC103", "CC104",
+  "CC110", "CC111", "CC112", "CC113",
+  "CC120", "CC121", "CC122",
+  "CC200", "CC201", "CC202", "CC203",
+  "CC210", "CC211", "CC212",
+  "CC300", "CC301", "CC302", "exact exchange"
+};
+
+/* Range-separated hybrid */
+#define N_PAR_C 43
+static const char *names_c[N_PAR_C] = {
+  "_CC000", "_CC001", "_CC002", "_CC003", "_CC004", "_CC005",
+  "_CC010", "_CC011", "_CC012", "_CC013", "_CC014",
+  "_CC020", "_CC021", "_CC022", "_CC023",
+  "_CC030", "_CC031", "_CC032",
+  "_CC100", "_CC101", "_CC102", "_CC103", "_CC104",
+  "_CC110", "_CC111", "_CC112", "_CC113",
+  "_CC120", "_CC121", "_CC122",
+  "_CC200", "_CC201", "_CC202", "_CC203",
+  "_CC210", "_CC211", "_CC212",
+  "_CC300", "_CC301", "_CC302",
+  "_ax", "_sx", "_omega"
+};
+static const char *desc_c[N_PAR_C] = {
+  "CC000", "CC001", "CC002", "CC003", "CC004", "CC005",
+  "CC010", "CC011", "CC012", "CC013", "CC014",
+  "CC020", "CC021", "CC022", "CC023",
+  "CC030", "CC031", "CC032",
+  "CC100", "CC101", "CC102", "CC103", "CC104",
+  "CC110", "CC111", "CC112", "CC113",
+  "CC120", "CC121", "CC122",
+  "CC200", "CC201", "CC202", "CC203",
+  "CC210", "CC211", "CC212",
+  "CC300", "CC301", "CC302",
+  "exact exchange", "short-range exchange", "range separation"
+};
+
+static const double par_mn12_l[N_PAR_L] = {
     6.735981e-01, -2.270598e+00, -2.613712e+00,  3.993609e+00,  4.635575e+00, 1.250676e+00,
     8.444920e-01, -1.301173e+01, -1.777730e+01, -4.627211e+00,  5.976605e+00,
     1.142897e+00, -2.040226e+01, -2.382843e+01,  7.119109e+00,
@@ -41,9 +124,9 @@ static const mgga_x_mn12_params par_mn12_l = {{
     -2.070080e+00, -9.951913e+00,  8.731211e-01,  2.210891e+01,
     8.822633e+00,  2.499949e+01,  2.500000e+01,
     6.851693e-01, -7.406948e-02, -6.788000e-01
-  }};
+};
 
-static const mgga_x_mn12_params par_mn12_sx = {{
+static const double par_mn12_sx[N_PAR_C] = {
    5.226556e-01, -2.681208e-01, -4.670705e+00,  3.067320e+00,  4.095370e+00,  2.653023e+00,
    5.165969e-01, -2.035442e+01, -9.946472e+00,  2.938637e+00,  1.131100e+01,
    4.752452e+00, -3.061331e+00, -2.523173e+01,  1.710903e+01,
@@ -53,10 +136,11 @@ static const mgga_x_mn12_params par_mn12_sx = {{
    5.329122e-01, -6.666755e+00,  1.671429e+00,
   -3.311409e+00,  3.415913e-01, -6.413076e+00,  1.038584e+01,
    9.026277e+00,  1.929689e+01,  2.669232e+01,
-   1.517278e+00, -3.442503e+00,  1.100161e+00
-  }};
+   1.517278e+00, -3.442503e+00,  1.100161e+00,
+   0.00, 0.25, 0.11
+};
 
-static const mgga_x_mn12_params par_mn15_l = {{
+static const double par_mn15_l[N_PAR_L] = {
    0.670864162, -0.822003903, -1.022407046,  1.689460986, -0.00562032,  -0.110293849,
    0.972245178, -6.697641991, -4.322814495, -6.786641376, -5.687461462,
    9.419643818, 11.83939406,   5.086951311,  4.302369948,
@@ -67,9 +151,9 @@ static const mgga_x_mn12_params par_mn15_l = {{
   -1.525344043, -2.325875691,  1.141940663, -1.563165026,
    7.882032871, 11.93400684,   9.852928303,
    0.584030245, -0.720941131, -2.836037078
-  }};
+};
 
-static const mgga_x_mn12_params par_mn15 = {{
+static const double par_mn15[N_PAR_H] = {
    0.073852235, -0.839976156, -3.082660125, -1.02881285, -0.811697255,   -0.063404387,
    2.54805518,  -5.031578906,  0.31702159,  2.981868205, -0.749503735,
    0.231825661,  1.261961411,  1.665920815, 7.483304941,
@@ -79,97 +163,86 @@ static const mgga_x_mn12_params par_mn15 = {{
    0.121595877,  8.048348238, 21.91203659,
   -1.852335832, -3.4722735,   -1.564591493, -2.29578769,
    3.666482991, 10.87074639,  9.696691388,
-   0.630701064, -0.505825216, -3.562354535
-  }};
+   0.630701064, -0.505825216, -3.562354535,
+   0.44
+};
 
 static void
 mgga_x_mn12_init(xc_func_type *p)
 {
-  mgga_x_mn12_params *params;
-
   assert(p->params == NULL);
-  p->params = malloc(sizeof(mgga_x_mn12_params));
-  params = (mgga_x_mn12_params *) (p->params);
+  p->params = libxc_malloc(sizeof(mgga_x_mn12_params));
 
-  switch(p->info->number){
-  case XC_MGGA_X_MN12_L:
-    memcpy(params, &par_mn12_l, sizeof(mgga_x_mn12_params));
-    break;
-  case XC_HYB_MGGA_X_MN12_SX:
-    memcpy(params, &par_mn12_sx, sizeof(mgga_x_mn12_params));
-    p->cam_alpha = 0.00;
-    p->cam_beta  = 0.25;
-    p->cam_omega = 0.11;
-    break;
-  case XC_MGGA_X_MN15_L:
-    memcpy(params, &par_mn15_l, sizeof(mgga_x_mn12_params));
-    break;
-  case XC_HYB_MGGA_X_MN15:
-    memcpy(params, &par_mn15, sizeof(mgga_x_mn12_params));
-    p->cam_alpha = 0.44;
-    p->cam_beta  = 0.00;
-    p->cam_omega = 0.00;
-    break;
-  default:
-    fprintf(stderr, "Internal error in mgga_x_mn12\n");
-    exit(1);
-  }
+  if(p->info->number == XC_HYB_MGGA_X_MN12_SX)
+    xc_hyb_init_cam(p, 0.0, 0.0, 0.0);
+  else if(p->info->number == XC_HYB_MGGA_X_MN15)
+    xc_hyb_init_hybrid(p, 0.0);
 }
 
-#include "maple2c/mgga_x_mn12.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
-
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_x_mn12.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_x_mn12_l = {
   XC_MGGA_X_MN12_L,
   XC_EXCHANGE,
   "Minnesota MN12-L exchange functional",
   XC_FAMILY_MGGA,
   {&xc_ref_Peverati2012_13171, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-23,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {N_PAR_L, names_l, desc_l, par_mn12_l, set_ext_params_cpy},
   mgga_x_mn12_init, NULL,
-  NULL, NULL, work_mgga_c,
+  NULL, NULL, work_mgga,
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_x_mn12_sx = {
   XC_HYB_MGGA_X_MN12_SX,
   XC_EXCHANGE,
   "Minnesota MN12-SX hybrid exchange functional",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Peverati2012_16187, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HYB_CAM | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | XC_FLAGS_HYB_CAM | MAPLE2C_FLAGS,
+  1e-15,
+  {N_PAR_C, names_c, desc_c, par_mn12_sx, set_ext_params_cpy_cam},
   mgga_x_mn12_init, NULL,
-  NULL, NULL, work_mgga_c
+  NULL, NULL, work_mgga
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_x_mn15_l = {
   XC_MGGA_X_MN15_L,
   XC_EXCHANGE,
   "Minnesota MN15-L exchange functional",
   XC_FAMILY_MGGA,
   {&xc_ref_Yu2016_1280, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-23,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {N_PAR_L, names_l, desc_l, par_mn15_l, set_ext_params_cpy},
   mgga_x_mn12_init, NULL,
-  NULL, NULL, work_mgga_c,
+  NULL, NULL, work_mgga,
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_hyb_mgga_x_mn15 = {
   XC_HYB_MGGA_X_MN15,
   XC_EXCHANGE,
   "Minnesota MN15 hybrid exchange functional",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Yu2016_5032, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {N_PAR_H, names_h, desc_h, par_mn15, set_ext_params_cpy_exx},
   mgga_x_mn12_init, NULL,
-  NULL, NULL, work_mgga_c,
+  NULL, NULL, work_mgga,
 };
