@@ -19,20 +19,22 @@ mgga_xc_b97mv_init(xc_func_type *p)
   p->nlc_C = 0.01;
 }
 
-#include "maple2c/mgga_xc_b97mv.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_xc_b97mv.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_xc_b97m_v = {
   XC_MGGA_XC_B97M_V,
   XC_EXCHANGE_CORRELATION,
   "B97M-V exchange-correlation functional",
   XC_FAMILY_MGGA,
   {&xc_ref_Mardirossian2015_074111, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_VV10 | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-23,
-  0, NULL, NULL,
-  mgga_xc_b97mv_init, NULL, 
-  NULL, NULL, work_mgga_c,
+  XC_FLAGS_3D | XC_FLAGS_VV10 | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  mgga_xc_b97mv_init, NULL,
+  NULL, NULL, work_mgga,
 };
