@@ -11,22 +11,24 @@
 
 #define XC_MGGA_XC_CC06          229 /* Cancio and Chou 2006 */
 
-#include "maple2c/mgga_xc_cc06.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_xc_cc06.c"
+#include "work_mgga.c"
 
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_xc_cc06 = {
   XC_MGGA_XC_CC06,
   XC_EXCHANGE_CORRELATION,
   "Cancio and Chou 2006",
   XC_FAMILY_MGGA,
   {&xc_ref_Cancio2006_081202, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_NEEDS_LAPLACIAN | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-23,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, NULL, work_mgga_c,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_LAPLACIAN | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, NULL, work_mgga,
 };
 
